<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:i6="http://iuclid6.echa.europa.eu/namespaces/platform-fields/v1" xmlns:i6c="http://iuclid6.echa.europa.eu/namespaces/platform-container/v1" xmlns:xt="http://iuclid6.echa.europa.eu/namespaces/FLEXIBLE_SUMMARY-ToxicologicalProfile/2.0" version="1.0">
    <xsl:template match="/">
        <html>
            <head>
                <link href="iuclid6_style.css" rel="stylesheet" type="text/css"/>
            </head>
            <body>
                <table>
                    <tr/>
                    <xsl:apply-templates/>
                </table>
            </body>
        </html>
    </xsl:template>
    <xsl:template match="//i6c:PlatformMetadata | //i6c:Attachments | //i6c:ModificationHistory"/>
    <xsl:template match="//xt:FLEXIBLE_SUMMARY">
        <tr class="headerDocument">
            <td>Toxicological profile for humans and animals</td>
            <td>
                <hr/>
            </td>
        </tr>
        <xsl:apply-templates select="./@*"/>
        <xsl:apply-templates/>
    </xsl:template>
    <xsl:template match="//xt:AelExtrapolatedFromLongTermAel | //xt:AelExtrapolatedFromLongTermAel">
        <tr>
            <td class="label">AEL extrapolated from long term AEL</td>
            <td class="value">
                <xsl:value-of select=". "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:DataProtection">
        <tr>
            <td class="label"/>
            <td class="value">
                <xsl:apply-templates/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:MrlValue">
        <tr>
            <td class="label">MRL Value</td>
            <td class="value">
                <xsl:value-of select=". "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:AelLongTerm | //xt:AfterDoseDescriptorStartingPoint | //xt:AelMediumTerm | //xt:AfterDoseDescriptorStartingPointMediumTerm | //xt:AelShortTerm | //xt:AfterDoseDescriptorStartingPointShortTerm | //xt:AecAcceptableExposureConcentration | //xt:DoseDescriptorStartingPointPQ | //xt:ReferenceValuePQ | //xt:DoseDescriptorStartingPointPQ | //xt:Value | //xt:Dmel | //xt:DoseDescriptorStartingPointPQ">
        <tr>
            <td class="label">
                <xsl:choose>
                    <xsl:when test="name(.) = 'Dmel'">DMEL (Derived Minimum Effect Level)</xsl:when>
                    <xsl:when test="name(.) = 'AelShortTerm'">AEL acute</xsl:when>
                    <xsl:when test="name(.) = 'AfterDoseDescriptorStartingPointMediumTerm'"/>
                    <xsl:when test="name(.) = 'AfterDoseDescriptorStartingPointShortTerm'"/>
                    <xsl:when test="name(.) = 'AfterDoseDescriptorStartingPoint'"/>
                    <xsl:when test="name(.) = 'DoseDescriptorStartingPointPQ'"/>
                    <xsl:when test="name(.) = 'ReferenceValuePQ'"/>
                    <xsl:when test="name(.) = 'AelMediumTerm'">AEL medium-term</xsl:when>
                    <xsl:when test="name(.) = 'AecAcceptableExposureConcentration'">AEC (Acceptable Exposure Concentration)</xsl:when>
                    <xsl:when test="name(.) = 'Value'">Value</xsl:when>
                    <xsl:when test="name(.) = 'AelLongTerm'">AEL chronic</xsl:when>
                </xsl:choose>
            </td>
            <td class="value">
                <xsl:value-of select="./i6:value "/>
                <xsl:choose>
                    <xsl:when test="./i6:unitCode = '8098'"> ng/kg bw/day</xsl:when>
                    <xsl:when test="./i6:unitCode = '8099'"> µg/kg bw/day</xsl:when>
                    <xsl:when test="./i6:unitCode = '2085'"> mg/kg bw/day</xsl:when>
                    <xsl:when test="./i6:unitCode = '58345'"> mg/m³ air</xsl:when>
                    <xsl:when test="./i6:unitCode = '58346'"> mg/cm² skin</xsl:when>
                    <xsl:when test="./i6:unitCode = '2500'"> µg/L</xsl:when>
                    <xsl:when test="./i6:unitCode = '2098'"> mg/L</xsl:when>
                    <xsl:when test="./i6:unitCode = '1935'"> g/L</xsl:when>
                </xsl:choose>
                <xsl:value-of select="./i6:unitOther "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:Tier | //xt:MostSensitiveEndpointLongTerm | //xt:RouteOfOriginalStudyLongTerm | //xt:AelDerivationMethod | //xt:DoseDescriptorStartingPoint | //xt:MostSensitiveEndpointMediumTerm | //xt:RouteOfOriginalStudyMediumTerm | //xt:AelDerivationMethodMediumTerm | //xt:DoseDescriptorStartingPointMediumTerm | //xt:MostSensitiveEndpointShortTerm | //xt:RouteOfOriginalStudyShortTerm | //xt:AelDerivationMethodShortTerm | //xt:DoseDescriptorStartingPointShortTerm | //xt:Route | //xt:MostSensitiveEndpoint | //xt:RouteOfOriginalStudy | //xt:AecDerivationMethod | //xt:DoseDescriptorStartingPoint | //xt:ReferenceValue | //xt:MostSensitiveEndpoint | //xt:RouteOfOriginalStudy | //xt:ReferenceValueDerivationMethod | //xt:DoseDescriptorStartingPoint | //xt:MlrFor | //xt:MostSensitiveEndpoint | //xt:RouteOfOriginalStudy | //xt:DmelDerivationMethod | //xt:DoseDescriptorStartingPoint">
        <tr>
            <td class="label">
                <xsl:choose>
                    <xsl:when test="name(.) = 'ReferenceValueDerivationMethod'">Reference value derivation method</xsl:when>
                    <xsl:when test="name(.) = 'DoseDescriptorStartingPointShortTerm'">Dose descriptor starting point (after route to route extrapolation)</xsl:when>
                    <xsl:when test="name(.) = 'AelDerivationMethodMediumTerm'">AEL derivation method</xsl:when>
                    <xsl:when test="name(.) = 'Tier'">Tier</xsl:when>
                    <xsl:when test="name(.) = 'MostSensitiveEndpointLongTerm'">Most sensitive endpoint</xsl:when>
                    <xsl:when test="name(.) = 'ReferenceValue'">Reference Value</xsl:when>
                    <xsl:when test="name(.) = 'AecDerivationMethod'">AEC derivation method</xsl:when>
                    <xsl:when test="name(.) = 'DmelDerivationMethod'">DMEL derivation method</xsl:when>
                    <xsl:when test="name(.) = 'MostSensitiveEndpoint'">Most sensitive endpoint</xsl:when>
                    <xsl:when test="name(.) = 'RouteOfOriginalStudyLongTerm'">Route of original study</xsl:when>
                    <xsl:when test="name(.) = 'AelDerivationMethod'">AEL derivation method</xsl:when>
                    <xsl:when test="name(.) = 'RouteOfOriginalStudyShortTerm'">Route of original study</xsl:when>
                    <xsl:when test="name(.) = 'MostSensitiveEndpointShortTerm'">Most sensitive endpoint</xsl:when>
                    <xsl:when test="name(.) = 'RouteOfOriginalStudyMediumTerm'">Route of original study</xsl:when>
                    <xsl:when test="name(.) = 'AelDerivationMethodShortTerm'">AEL derivation method</xsl:when>
                    <xsl:when test="name(.) = 'MostSensitiveEndpointMediumTerm'">Most sensitive endpoint</xsl:when>
                    <xsl:when test="name(.) = 'DoseDescriptorStartingPoint'">Dose descriptor starting point (after route to route extrapolation)</xsl:when>
                    <xsl:when test="name(.) = 'RouteOfOriginalStudy'">Route of original study</xsl:when>
                    <xsl:when test="name(.) = 'MlrFor'">MLR for:</xsl:when>
                    <xsl:when test="name(.) = 'DoseDescriptorStartingPointMediumTerm'">Dose descriptor starting point (after route to route extrapolation)</xsl:when>
                    <xsl:when test="name(.) = 'Route'">Route</xsl:when>
                </xsl:choose>
            </td>
            <td class="value">
                <xsl:choose>
                    <xsl:when test="./i6:value = '58350'">Tier I</xsl:when>
                    <xsl:when test="./i6:value = '58351'">Tier II</xsl:when>
                    <xsl:when test="./i6:value = '5676'">acute toxicity</xsl:when>
                    <xsl:when test="./i6:value = '5677'">repeated dose toxicity</xsl:when>
                    <xsl:when test="./i6:value = '6626'">effect on fertility</xsl:when>
                    <xsl:when test="./i6:value = '4155'">developmental toxicity / teratogenicity</xsl:when>
                    <xsl:when test="./i6:value = '2936'">neurotoxicity</xsl:when>
                    <xsl:when test="./i6:value = '2862'">immunotoxicity</xsl:when>
                    <xsl:when test="./i6:value = '6627'">sensitisation (skin)</xsl:when>
                    <xsl:when test="./i6:value = '6628'">sensitisation (respiratory tract)</xsl:when>
                    <xsl:when test="./i6:value = '2743'">carcinogenicity</xsl:when>
                    <xsl:when test="./i6:value = '6629'">skin irritation/corrosion</xsl:when>
                    <xsl:when test="./i6:value = '6630'">irritation (respiratory tract)</xsl:when>
                    <xsl:when test="./i6:value = '4153'">genetic toxicity</xsl:when>
                    <xsl:when test="./i6:value = '5136'">Oral</xsl:when>
                    <xsl:when test="./i6:value = '5137'">Dermal</xsl:when>
                    <xsl:when test="./i6:value = '5138'">By inhalation</xsl:when>
                    <xsl:when test="./i6:value = '58344'">ECHA Biocides Guidance</xsl:when>
                    <xsl:when test="./i6:value = '1342'">other:</xsl:when>
                    <xsl:when test="./i6:value = '1109'">NOAEL</xsl:when>
                    <xsl:when test="./i6:value = '937'">LOAEL</xsl:when>
                    <xsl:when test="./i6:value = '5672'">BMDL05</xsl:when>
                    <xsl:when test="./i6:value = '5673'">BMD05</xsl:when>
                    <xsl:when test="./i6:value = '5674'">BMDL10</xsl:when>
                    <xsl:when test="./i6:value = '126'">BMD:</xsl:when>
                    <xsl:when test="./i6:value = '4147'">NOAEC</xsl:when>
                    <xsl:when test="./i6:value = '4148'">LOAEC</xsl:when>
                    <xsl:when test="./i6:value = '5760'">BMC05</xsl:when>
                    <xsl:when test="./i6:value = '5759'">BMCL05</xsl:when>
                    <xsl:when test="./i6:value = '5761'">BMCL10</xsl:when>
                    <xsl:when test="./i6:value = '122'">BMC:</xsl:when>
                    <xsl:when test="./i6:value = '58347'">ADI (if residues in food or feed)</xsl:when>
                    <xsl:when test="./i6:value = '58348'">ARfD (acute reference dose)</xsl:when>
                    <xsl:when test="./i6:value = '58349'">TMDI (theoretical maximum daily intake)</xsl:when>
                    <xsl:when test="./i6:value = '58385'">animal husbandry</xsl:when>
                    <xsl:when test="./i6:value = '58386'">food</xsl:when>
                    <xsl:when test="./i6:value = '5675'">T25</xsl:when>
                    <xsl:when test="./i6:value = '58352'">BMD10</xsl:when>
                </xsl:choose>
                <xsl:value-of select="./i6:other "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:ExternalReferenceValuesForRootSpecificEffects | //xt:ReferenceValuesForExposureViaFood">
        <tr class="headerBlock">
            <td>
                <xsl:choose>
                    <xsl:when test="name(.) = 'ExternalReferenceValuesForRootSpecificEffects'"/>
                    <xsl:when test="name(.) = 'ReferenceValuesForExposureViaFood'"/>
                </xsl:choose>
            </td>
            <td>
                <hr/>
            </td>
        </tr>
        <xsl:apply-templates select="./@*"/>
        <xsl:apply-templates/>
    </xsl:template>
    <xsl:template match="//xt:AdministrativeDataSummary | //xt:HumanHealthHazardCharacteristics | //xt:SystemicAel | //xt:LongTermExposure | //xt:AelRelatedInformation | //xt:MediumTermExposure | //xt:AelRelatedInformationMediumTerm | //xt:ShortTermExposure | //xt:AelRelatedInformationShortTerm | //xt:ExternalReferenceValuesForRootSpecificEffects | //xt:ReferenceValuesForExposureViaFood | //xt:Mrl | //xt:DrinkingWaterLimit | //xt:NonThresholdCarcinogenicSubstances | //xt:DmelRelatedInformation | //xt:Discussion">
        <tr class="headerBlock">
            <td>
                <xsl:choose>
                    <xsl:when test="name(.) = 'HumanHealthHazardCharacteristics'">Human health hazard characteristics / Human health hazard characteristics</xsl:when>
                    <xsl:when test="name(.) = 'Mrl'">MRL (maximum residue limit)</xsl:when>
                    <xsl:when test="name(.) = 'ShortTermExposure'">Acute/short term exposure</xsl:when>
                    <xsl:when test="name(.) = 'AdministrativeDataSummary'">Administrative data</xsl:when>
                    <xsl:when test="name(.) = 'LongTermExposure'">Long term exposure / Long term exposure</xsl:when>
                    <xsl:when test="name(.) = 'ExternalReferenceValuesForRootSpecificEffects'">External Reference Values for Route-Specific Effects</xsl:when>
                    <xsl:when test="name(.) = 'SystemicAel'">Systemic AEL (Acceptable Exposure Level) / Systemic AEL (Acceptable Exposure Level)</xsl:when>
                    <xsl:when test="name(.) = 'DmelRelatedInformation'">DMEL related information</xsl:when>
                    <xsl:when test="name(.) = 'AelRelatedInformationMediumTerm'">AEL related information / AEL related information</xsl:when>
                    <xsl:when test="name(.) = 'NonThresholdCarcinogenicSubstances'">Non threshold carcinogenic substances / Non threshold carcinogenic substances</xsl:when>
                    <xsl:when test="name(.) = 'MediumTermExposure'">Medium term exposure / Medium term exposure</xsl:when>
                    <xsl:when test="name(.) = 'AelRelatedInformationShortTerm'">AEL related information / AEL related information</xsl:when>
                    <xsl:when test="name(.) = 'DrinkingWaterLimit'">Drinking Water Limit</xsl:when>
                    <xsl:when test="name(.) = 'AelRelatedInformation'">AEL related information / AEL related information</xsl:when>
                    <xsl:when test="name(.) = 'ReferenceValuesForExposureViaFood'">Reference Values for exposure via Food</xsl:when>
                    <xsl:when test="name(.) = 'Discussion'">Additional information</xsl:when>
                </xsl:choose>
            </td>
            <td>
                <hr/>
            </td>
        </tr>
        <xsl:apply-templates select="./@*"/>
        <xsl:apply-templates/>
    </xsl:template>
    <xsl:template match="//xt:OverallAssessmentFactor | //xt:JustificationForRouteToRouteExtrapolation | //xt:AfForDoseResponseRelationship | //xt:JustificationForDoseResponseRelationship | //xt:AfForDifferencesInDurationOfExposure | //xt:JustificationForDifferencesInDurationOfExposure | //xt:AfForInterspeciesDifferences | //xt:JustificationForInterspeciesDifferences | //xt:AfForOtherIntraspeciesDifferences | //xt:JustificationForOtherIntraspeciesDifferences | //xt:AfForIntraspeciesDifferences | //xt:JustificationForIntraspeciesDifferences | //xt:AfForTheQualityOfTheWholeDatabase | //xt:JustificationForTheQualityOfTheWholeDatabase | //xt:AfForRemainingUncertainties | //xt:JustificationForRemainingUncertainties | //xt:JustificationAndComments | //xt:OverallAssessmentFactorMediumTerm | //xt:JustificationForRouteToRouteExtrapolationMediumTerm | //xt:AfForDoseResponseRelationshipMediumTerm | //xt:JustificationForDoseResponseRelationshipMediumTerm | //xt:AfForDifferencesInDurationOfExposureMediumTerm | //xt:JustificationForDifferencesInDurationOfExposureMediumTerm | //xt:AfForInterspeciesDifferencesMediumTerm | //xt:JustificationForInterspeciesDifferencesMediumTerm | //xt:AfForOtherIntraspeciesDifferencesMediumTerm | //xt:JustificationForOtherIntraspeciesDifferencesMediumTerm | //xt:AfForIntraspeciesDifferencesMediumTerm | //xt:JustificationForIntraspeciesDifferencesMediumTerm | //xt:AfForTheQualityOfTheWholeDatabaseMediumTerm | //xt:JustificationForTheQualityOfTheWholeDatabaseMediumTerm | //xt:AfForRemainingUncertaintiesMediumTerm | //xt:JustificationForRemainingUncertaintiesMediumTerm | //xt:JustificationAndCommentsMediumTerm | //xt:OverallAssessmentFactorShortTerm | //xt:JustificationForRouteToRouteExtrapolationShortTerm | //xt:AfForDoseResponseRelationshipShortTerm | //xt:JustificationForDoseResponseRelationshipShortTerm | //xt:AfForDifferencesInDurationOfExposureShortTerm | //xt:JustificationForDifferencesInDurationOfExposureShortTerm | //xt:AfForInterspeciesDifferencesShortTerm | //xt:JustificationForInterspeciesDifferencesShortTerm | //xt:AfForOtherIntraspeciesDifferencesShortTerm | //xt:JustificationForOtherIntraspeciesDifferencesShortTerm | //xt:AfForIntraspeciesDifferencesShortTerm | //xt:JustificationForIntraspeciesDifferencesShortTerm | //xt:AfForTheQualityOfTheWholeDatabaseShortTerm | //xt:JustificationForTheQualityOfTheWholeDatabaseShortTerm | //xt:AfForRemainingUncertaintiesShortTerm | //xt:JustificationForRemainingUncertaintiesShortTerm | //xt:JustificationAndCommentsShortTerm | //xt:OverallAssessmentFactorAf | //xt:JustificationForRouteToRouteExtrapolation | //xt:AfForDoseResponseRelationship | //xt:JustificationForDoseResponseRelationship | //xt:AfForDifferencesInDurationOfExposure | //xt:JustificationForDifferencesInDurationOfExposure | //xt:AfForInterspeciesDifferences | //xt:JustificationForInterspeciesDifferences | //xt:AfForOtherIntraspeciesDifferences | //xt:JustificationForOtherIntraspeciesDifferences | //xt:AfForIntraspeciesDifferences | //xt:JustificationForIntraspeciesDifferences | //xt:AfForTheQualityOfTheWholeDatabase | //xt:JustificationForTheQualityOfTheWholeDatabase | //xt:AfForRemainingUncertainties | //xt:JustificationForRemainingUncertainties | //xt:JustificationAndComments | //xt:OverallAssessmentFactorAf | //xt:JustificationForRouteToRouteExtrapolation | //xt:AfForDoseResponseRelationship | //xt:JustificationForDoseResponseRelationship | //xt:AfForDifferencesInDurationOfExposure | //xt:JustificationForDifferencesInDurationOfExposure | //xt:AfForInterspeciesDifferences | //xt:JustificationForInterspeciesDifferences | //xt:AfForOtherIntraspeciesDifferences | //xt:JustificationForOtherIntraspeciesDifferences | //xt:AfForIntraspeciesDifferences | //xt:JustificationForIntraspeciesDifferences | //xt:AfForTheQualityOfTheWholeDatabase | //xt:JustificationForTheQualityOfTheWholeDatabase | //xt:AfForRemainingUncertainties | //xt:JustificationForRemainingUncertainties | //xt:JustificationAndComments | //xt:JustificationAndComments | //xt:JustificationAndComments | //xt:OverallAssessmentFactorAf | //xt:JustificationForRouteToRouteExtrapolation | //xt:AfForDoseResponseRelationship | //xt:JustificationForDoseResponseRelationship | //xt:AfForDifferencesInDurationOfExposure | //xt:JustificationForDifferencesInDurationOfExposure | //xt:AfForInterspeciesDifferences | //xt:JustificationForInterspeciesDifferences | //xt:AfForOtherIntraspeciesDifferences | //xt:JustificationForOtherIntraspeciesDifferences | //xt:AfForIntraspeciesDifferences | //xt:JustificationForIntraspeciesDifferences | //xt:AfForTheQualityOfTheWholeDatabase | //xt:JustificationForTheQualityOfTheWholeDatabase | //xt:AfForRemainingUncertainties | //xt:JustificationForRemainingUncertainties | //xt:AfForNatureOfCarcinogenicProcess | //xt:JustificationForNatureOfCarcinogenicProcess | //xt:AfForPointOfComparison | //xt:JustificationForPointOfComparison | //xt:JustificationAndComments | //xt:Discussion">
        <tr>
            <td class="label">
                <xsl:choose>
                    <xsl:when test="name(.) = 'JustificationForIntraspeciesDifferencesMediumTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForIntraspeciesDifferences'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForDoseResponseRelationshipMediumTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForInterspeciesDifferencesMediumTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'AfForOtherIntraspeciesDifferencesMediumTerm'">AF for other intraspecies differences</xsl:when>
                    <xsl:when test="name(.) = 'AfForDifferencesInDurationOfExposureShortTerm'">AF for differences in duration of exposure</xsl:when>
                    <xsl:when test="name(.) = 'AfForInterspeciesDifferencesShortTerm'">AF for interspecies differences</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForOtherIntraspeciesDifferencesShortTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForOtherIntraspeciesDifferences'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'AfForOtherIntraspeciesDifferences'">AF for other intraspecies differences</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForTheQualityOfTheWholeDatabase'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForRemainingUncertaintiesShortTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'AfForTheQualityOfTheWholeDatabase'">AF for the quality of the whole database</xsl:when>
                    <xsl:when test="name(.) = 'AfForDoseResponseRelationshipMediumTerm'">AF for dose response relationship</xsl:when>
                    <xsl:when test="name(.) = 'OverallAssessmentFactor'">Overall assessment factor (AF)</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForDoseResponseRelationshipShortTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'AfForIntraspeciesDifferencesShortTerm'">AF for intraspecies differences</xsl:when>
                    <xsl:when test="name(.) = 'OverallAssessmentFactorShortTerm'">Overall assessment factor (AF)</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForDifferencesInDurationOfExposureMediumTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'AfForOtherIntraspeciesDifferencesShortTerm'">AF for other intraspecies differences</xsl:when>
                    <xsl:when test="name(.) = 'OverallAssessmentFactorMediumTerm'">Overall assessment factor (AF)</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForRouteToRouteExtrapolationShortTerm'">Justification for route to route extrapolation</xsl:when>
                    <xsl:when test="name(.) = 'AfForNatureOfCarcinogenicProcess'">AF for nature of carcinogenic process</xsl:when>
                    <xsl:when test="name(.) = 'AfForDifferencesInDurationOfExposure'">AF for differences in duration of exposure</xsl:when>
                    <xsl:when test="name(.) = 'AfForDifferencesInDurationOfExposureMediumTerm'">AF for differences in duration of exposure</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForDoseResponseRelationship'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'AfForRemainingUncertaintiesMediumTerm'">AF for remaining uncertainties</xsl:when>
                    <xsl:when test="name(.) = 'AfForInterspeciesDifferences'">AF for interspecies differences</xsl:when>
                    <xsl:when test="name(.) = 'JustificationAndCommentsMediumTerm'">Justification and comments</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForPointOfComparison'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'Discussion'"/>
                    <xsl:when test="name(.) = 'AfForRemainingUncertainties'">AF for remaining uncertainties</xsl:when>
                    <xsl:when test="name(.) = 'AfForRemainingUncertaintiesShortTerm'">AF for remaining uncertainties</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForRemainingUncertaintiesMediumTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForOtherIntraspeciesDifferencesMediumTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForNatureOfCarcinogenicProcess'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'AfForDoseResponseRelationshipShortTerm'">AF for dose response relationship</xsl:when>
                    <xsl:when test="name(.) = 'AfForIntraspeciesDifferencesMediumTerm'">AF for intraspecies differences</xsl:when>
                    <xsl:when test="name(.) = 'OverallAssessmentFactorAf'">Overall assessment factor (AF)</xsl:when>
                    <xsl:when test="name(.) = 'AfForTheQualityOfTheWholeDatabaseMediumTerm'">AF for the quality of the whole database</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForRouteToRouteExtrapolation'">Justification for route to route extrapolation</xsl:when>
                    <xsl:when test="name(.) = 'AfForIntraspeciesDifferences'">AF for intraspecies differences</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForTheQualityOfTheWholeDatabaseMediumTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'JustificationAndComments'">Justification and comments</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForIntraspeciesDifferencesShortTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForInterspeciesDifferences'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'AfForPointOfComparison'">AF for point of comparison</xsl:when>
                    <xsl:when test="name(.) = 'AfForTheQualityOfTheWholeDatabaseShortTerm'">AF for the quality of the whole database</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForRemainingUncertainties'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForTheQualityOfTheWholeDatabaseShortTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForDifferencesInDurationOfExposure'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForRouteToRouteExtrapolationMediumTerm'">Justification for route to route extrapolation</xsl:when>
                    <xsl:when test="name(.) = 'AfForInterspeciesDifferencesMediumTerm'">AF for interspecies differences</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForDifferencesInDurationOfExposureShortTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'AfForDoseResponseRelationship'">AF for dose response relationship</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForInterspeciesDifferencesShortTerm'">Justification</xsl:when>
                    <xsl:when test="name(.) = 'JustificationAndCommentsShortTerm'">Justification and comments</xsl:when>
                </xsl:choose>
            </td>
            <td class="value">
                <xsl:value-of select=". "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//i6:country/i6:value">
        <xsl:choose>
            <xsl:when test=". = '3446'">Åland Islands </xsl:when>
            <xsl:when test=". = '2683'">Afghanistan </xsl:when>
            <xsl:when test=". = '2684'">Albania </xsl:when>
            <xsl:when test=". = '2685'">Algeria </xsl:when>
            <xsl:when test=". = '2686'">American Samoa </xsl:when>
            <xsl:when test=". = '2688'">Andorra </xsl:when>
            <xsl:when test=". = '2689'">Angola </xsl:when>
            <xsl:when test=". = '2690'">Anguilla </xsl:when>
            <xsl:when test=". = '2692'">Antarctica </xsl:when>
            <xsl:when test=". = '2695'">Antigua and Barbuda </xsl:when>
            <xsl:when test=". = '2696'">Argentina </xsl:when>
            <xsl:when test=". = '2697'">Armenia </xsl:when>
            <xsl:when test=". = '2698'">Aruba </xsl:when>
            <xsl:when test=". = '107'">Australia </xsl:when>
            <xsl:when test=". = '108'">Austria </xsl:when>
            <xsl:when test=". = '2701'">Azerbaijan </xsl:when>
            <xsl:when test=". = '2702'">Bahamas </xsl:when>
            <xsl:when test=". = '2703'">Bahrain </xsl:when>
            <xsl:when test=". = '2704'">Bangladesh </xsl:when>
            <xsl:when test=". = '2705'">Barbados </xsl:when>
            <xsl:when test=". = '2707'">Belarus </xsl:when>
            <xsl:when test=". = '147'">Belgium </xsl:when>
            <xsl:when test=". = '2708'">Belize </xsl:when>
            <xsl:when test=". = '2709'">Benin </xsl:when>
            <xsl:when test=". = '2710'">Bermuda </xsl:when>
            <xsl:when test=". = '2711'">Bhutan </xsl:when>
            <xsl:when test=". = '2720'">Bolivia, Plurinational State of </xsl:when>
            <xsl:when test=". = '2722'">Bosnia and Herzegovina </xsl:when>
            <xsl:when test=". = '2723'">Botswana </xsl:when>
            <xsl:when test=". = '2724'">Bouvet Island </xsl:when>
            <xsl:when test=". = '2725'">Brazil </xsl:when>
            <xsl:when test=". = '2726'">British Indian Ocean Territory </xsl:when>
            <xsl:when test=". = '2727'">Brunei Darussalam </xsl:when>
            <xsl:when test=". = '184'">Bulgaria </xsl:when>
            <xsl:when test=". = '2729'">Burkina Faso </xsl:when>
            <xsl:when test=". = '2730'">Burundi </xsl:when>
            <xsl:when test=". = '2734'">Cambodia </xsl:when>
            <xsl:when test=". = '2735'">Cameroon </xsl:when>
            <xsl:when test=". = '206'">Canada </xsl:when>
            <xsl:when test=". = '2736'">Cape Verde </xsl:when>
            <xsl:when test=". = '2746'">Cayman Islands </xsl:when>
            <xsl:when test=". = '2747'">Central African Republic </xsl:when>
            <xsl:when test=". = '2748'">Chad </xsl:when>
            <xsl:when test=". = '2749'">Chile </xsl:when>
            <xsl:when test=". = '2750'">China </xsl:when>
            <xsl:when test=". = '2751'">Christmas Island </xsl:when>
            <xsl:when test=". = '2754'">Cocos (Keeling) Islands </xsl:when>
            <xsl:when test=". = '2755'">Colombia </xsl:when>
            <xsl:when test=". = '2759'">Comoros </xsl:when>
            <xsl:when test=". = '2764'">Congo </xsl:when>
            <xsl:when test=". = '2765'">Congo, The Democratic Republic of the </xsl:when>
            <xsl:when test=". = '2769'">Cook Islands </xsl:when>
            <xsl:when test=". = '2771'">Costa Rica </xsl:when>
            <xsl:when test=". = '286'">Croatia </xsl:when>
            <xsl:when test=". = '2774'">Côte d'Ivoire </xsl:when>
            <xsl:when test=". = '2773'">Cuba </xsl:when>
            <xsl:when test=". = '304'">Cyprus </xsl:when>
            <xsl:when test=". = '307'">Czech Republic </xsl:when>
            <xsl:when test=". = '333'">Denmark </xsl:when>
            <xsl:when test=". = '2790'">Djibouti </xsl:when>
            <xsl:when test=". = '2791'">Dominica </xsl:when>
            <xsl:when test=". = '2792'">Dominican Republic </xsl:when>
            <xsl:when test=". = '2799'">Ecuador </xsl:when>
            <xsl:when test=". = '2800'">Egypt </xsl:when>
            <xsl:when test=". = '2801'">El Salvador </xsl:when>
            <xsl:when test=". = '2803'">Equatorial Guinea </xsl:when>
            <xsl:when test=". = '2804'">Eritrea </xsl:when>
            <xsl:when test=". = '754'">Estonia </xsl:when>
            <xsl:when test=". = '2805'">Ethiopia </xsl:when>
            <xsl:when test=". = '2813'">Falkland Islands (Malvinas) </xsl:when>
            <xsl:when test=". = '2815'">Faroe Islands </xsl:when>
            <xsl:when test=". = '2817'">Fiji </xsl:when>
            <xsl:when test=". = '766'">Finland </xsl:when>
            <xsl:when test=". = '779'">France </xsl:when>
            <xsl:when test=". = '2825'">French Guiana </xsl:when>
            <xsl:when test=". = '2826'">French Polynesia </xsl:when>
            <xsl:when test=". = '2827'">French Southern Territories </xsl:when>
            <xsl:when test=". = '2828'">Gabon </xsl:when>
            <xsl:when test=". = '2829'">Gambia </xsl:when>
            <xsl:when test=". = '2834'">Georgia </xsl:when>
            <xsl:when test=". = '807'">Germany </xsl:when>
            <xsl:when test=". = '2835'">Ghana </xsl:when>
            <xsl:when test=". = '2836'">Gibraltar </xsl:when>
            <xsl:when test=". = '810'">Greece </xsl:when>
            <xsl:when test=". = '2838'">Greenland </xsl:when>
            <xsl:when test=". = '2839'">Grenada </xsl:when>
            <xsl:when test=". = '2840'">Guadeloupe </xsl:when>
            <xsl:when test=". = '2841'">Guam </xsl:when>
            <xsl:when test=". = '2842'">Guatemala </xsl:when>
            <xsl:when test=". = '7818'">Guernsey </xsl:when>
            <xsl:when test=". = '2843'">Guinea </xsl:when>
            <xsl:when test=". = '2844'">Guinea-Bissau </xsl:when>
            <xsl:when test=". = '2845'">Guyana </xsl:when>
            <xsl:when test=". = '2846'">Haiti </xsl:when>
            <xsl:when test=". = '2851'">Heard Island and McDonald Islands </xsl:when>
            <xsl:when test=". = '2854'">Holy See (Vatican City State) </xsl:when>
            <xsl:when test=". = '2855'">Honduras </xsl:when>
            <xsl:when test=". = '2856'">Hong Kong </xsl:when>
            <xsl:when test=". = '845'">Hungary </xsl:when>
            <xsl:when test=". = '882'">Iceland </xsl:when>
            <xsl:when test=". = '2865'">India </xsl:when>
            <xsl:when test=". = '2866'">Indonesia </xsl:when>
            <xsl:when test=". = '2870'">Iran, Islamic Republic of </xsl:when>
            <xsl:when test=". = '2871'">Iraq </xsl:when>
            <xsl:when test=". = '911'">Ireland </xsl:when>
            <xsl:when test=". = '7819'">Isle of man </xsl:when>
            <xsl:when test=". = '2876'">Israel </xsl:when>
            <xsl:when test=". = '916'">Italy </xsl:when>
            <xsl:when test=". = '2877'">Jamaica </xsl:when>
            <xsl:when test=". = '918'">Japan </xsl:when>
            <xsl:when test=". = '7820'">Jersey </xsl:when>
            <xsl:when test=". = '2878'">Jordan </xsl:when>
            <xsl:when test=". = '2879'">Kazakhstan </xsl:when>
            <xsl:when test=". = '2880'">Kenya </xsl:when>
            <xsl:when test=". = '2881'">Kiribati </xsl:when>
            <xsl:when test=". = '2882'">Korea, Democratic People's Republic of </xsl:when>
            <xsl:when test=". = '2883'">Korea, Republic Of </xsl:when>
            <xsl:when test=". = '2884'">Kuwait </xsl:when>
            <xsl:when test=". = '2885'">Kyrgyzstan </xsl:when>
            <xsl:when test=". = '2886'">Lao People's Democratic Republic </xsl:when>
            <xsl:when test=". = '985'">Latvia </xsl:when>
            <xsl:when test=". = '2887'">Lebanon </xsl:when>
            <xsl:when test=". = '2888'">Lesotho </xsl:when>
            <xsl:when test=". = '2889'">Liberia </xsl:when>
            <xsl:when test=". = '2890'">Libyan Arab Jamahiriya </xsl:when>
            <xsl:when test=". = '2891'">Liechtenstein </xsl:when>
            <xsl:when test=". = '1024'">Lithuania </xsl:when>
            <xsl:when test=". = '1041'">Luxembourg </xsl:when>
            <xsl:when test=". = '2896'">Macao </xsl:when>
            <xsl:when test=". = '2897'">Macedonia, the former Yugoslav Republic of </xsl:when>
            <xsl:when test=". = '2898'">Madagascar </xsl:when>
            <xsl:when test=". = '2899'">Malawi </xsl:when>
            <xsl:when test=". = '2900'">Malaysia </xsl:when>
            <xsl:when test=". = '2901'">Maldives </xsl:when>
            <xsl:when test=". = '2902'">Mali </xsl:when>
            <xsl:when test=". = '1048'">Malta </xsl:when>
            <xsl:when test=". = '2904'">Marshall Islands </xsl:when>
            <xsl:when test=". = '2905'">Martinique </xsl:when>
            <xsl:when test=". = '2908'">Mauritania </xsl:when>
            <xsl:when test=". = '2909'">Mauritius </xsl:when>
            <xsl:when test=". = '2910'">Mayotte </xsl:when>
            <xsl:when test=". = '1067'">Mexico </xsl:when>
            <xsl:when test=". = '3877'">Micronesia, Federated States of </xsl:when>
            <xsl:when test=". = '2919'">Moldova, Republic of </xsl:when>
            <xsl:when test=". = '2921'">Monaco </xsl:when>
            <xsl:when test=". = '2922'">Mongolia </xsl:when>
            <xsl:when test=". = '7821'">Montenegro </xsl:when>
            <xsl:when test=". = '2924'">Montserrat </xsl:when>
            <xsl:when test=". = '2925'">Morocco </xsl:when>
            <xsl:when test=". = '2926'">Mozambique </xsl:when>
            <xsl:when test=". = '2930'">Myanmar </xsl:when>
            <xsl:when test=". = '2932'">Namibia </xsl:when>
            <xsl:when test=". = '2933'">Nauru </xsl:when>
            <xsl:when test=". = '2934'">Nepal </xsl:when>
            <xsl:when test=". = '1158'">Netherlands </xsl:when>
            <xsl:when test=". = '2935'">Netherlands Antilles </xsl:when>
            <xsl:when test=". = '2938'">New Caledonia </xsl:when>
            <xsl:when test=". = '1161'">New Zealand </xsl:when>
            <xsl:when test=". = '2939'">Nicaragua </xsl:when>
            <xsl:when test=". = '2940'">Niger </xsl:when>
            <xsl:when test=". = '2941'">Nigeria </xsl:when>
            <xsl:when test=". = '2942'">Niue </xsl:when>
            <xsl:when test=". = '2945'">Norfolk Island </xsl:when>
            <xsl:when test=". = '2946'">Northern Mariana Islands </xsl:when>
            <xsl:when test=". = '1175'">Norway </xsl:when>
            <xsl:when test=". = '2977'">Oman </xsl:when>
            <xsl:when test=". = '2984'">Pakistan </xsl:when>
            <xsl:when test=". = '2985'">Palau </xsl:when>
            <xsl:when test=". = '2986'">Palestinian Territory, occupied </xsl:when>
            <xsl:when test=". = '2987'">Panama </xsl:when>
            <xsl:when test=". = '2988'">Papua New Guinea </xsl:when>
            <xsl:when test=". = '2989'">Paraguay </xsl:when>
            <xsl:when test=". = '2994'">Peru </xsl:when>
            <xsl:when test=". = '2995'">Philippines </xsl:when>
            <xsl:when test=". = '3000'">Pitcairn </xsl:when>
            <xsl:when test=". = '1394'">Poland </xsl:when>
            <xsl:when test=". = '1401'">Portugal </xsl:when>
            <xsl:when test=". = '3027'">Puerto Rico </xsl:when>
            <xsl:when test=". = '3028'">Qatar </xsl:when>
            <xsl:when test=". = '1496'">Romania </xsl:when>
            <xsl:when test=". = '3177'">Réunion </xsl:when>
            <xsl:when test=". = '3175'">Russian Federation </xsl:when>
            <xsl:when test=". = '3176'">Rwanda </xsl:when>
            <xsl:when test=". = '7823'">Saint Barthélemy </xsl:when>
            <xsl:when test=". = '3318'">Saint Helena </xsl:when>
            <xsl:when test=". = '3319'">Saint Kitts and Nevis </xsl:when>
            <xsl:when test=". = '3320'">Saint Lucia </xsl:when>
            <xsl:when test=". = '7824'">Saint Martin </xsl:when>
            <xsl:when test=". = '3321'">Saint Pierre and Miquelon </xsl:when>
            <xsl:when test=". = '3322'">Saint Vincent and the Grenadines </xsl:when>
            <xsl:when test=". = '3323'">Samoa </xsl:when>
            <xsl:when test=". = '3324'">San Marino </xsl:when>
            <xsl:when test=". = '3325'">Sao Tome and Principe </xsl:when>
            <xsl:when test=". = '3326'">Saudi Arabia </xsl:when>
            <xsl:when test=". = '3328'">Senegal </xsl:when>
            <xsl:when test=". = '3332'">Serbia </xsl:when>
            <xsl:when test=". = '3333'">Seychelles </xsl:when>
            <xsl:when test=". = '3336'">Sierra Leone </xsl:when>
            <xsl:when test=". = '3337'">Singapore </xsl:when>
            <xsl:when test=". = '3339'">Slovakia </xsl:when>
            <xsl:when test=". = '1562'">Slovenia </xsl:when>
            <xsl:when test=". = '3340'">Solomon Islands </xsl:when>
            <xsl:when test=". = '3343'">Somalia </xsl:when>
            <xsl:when test=". = '3344'">South Africa </xsl:when>
            <xsl:when test=". = '3345'">South Georgia and the South Sandwich Islands </xsl:when>
            <xsl:when test=". = '1567'">Spain </xsl:when>
            <xsl:when test=". = '3346'">Sri Lanka </xsl:when>
            <xsl:when test=". = '3352'">Sudan </xsl:when>
            <xsl:when test=". = '3355'">Suriname </xsl:when>
            <xsl:when test=". = '3357'">Svalbard and Jan Mayen </xsl:when>
            <xsl:when test=". = '3358'">Swaziland </xsl:when>
            <xsl:when test=". = '1591'">Sweden </xsl:when>
            <xsl:when test=". = '1595'">Switzerland </xsl:when>
            <xsl:when test=". = '3359'">Syrian Arab Republic </xsl:when>
            <xsl:when test=". = '3362'">Taiwan, Province of China </xsl:when>
            <xsl:when test=". = '3363'">Tajikistan </xsl:when>
            <xsl:when test=". = '3364'">Tanzania, United Republic of </xsl:when>
            <xsl:when test=". = '3366'">Thailand </xsl:when>
            <xsl:when test=". = '3370'">Timor-Leste </xsl:when>
            <xsl:when test=". = '3371'">Togo </xsl:when>
            <xsl:when test=". = '3372'">Tokelau </xsl:when>
            <xsl:when test=". = '3373'">Tonga </xsl:when>
            <xsl:when test=". = '3393'">Trinidad and Tobago </xsl:when>
            <xsl:when test=". = '3394'">Tunisia </xsl:when>
            <xsl:when test=". = '1641'">Turkey </xsl:when>
            <xsl:when test=". = '3395'">Turkmenistan </xsl:when>
            <xsl:when test=". = '3396'">Turks and Caicos Islands </xsl:when>
            <xsl:when test=". = '3397'">Tuvalu </xsl:when>
            <xsl:when test=". = '3402'">Uganda </xsl:when>
            <xsl:when test=". = '3403'">Ukraine </xsl:when>
            <xsl:when test=". = '3406'">United Arab Emirates </xsl:when>
            <xsl:when test=". = '1651'">United Kingdom </xsl:when>
            <xsl:when test=". = '1652'">United States </xsl:when>
            <xsl:when test=". = '3407'">United States Minor Outlying Islands </xsl:when>
            <xsl:when test=". = '3410'">Uruguay </xsl:when>
            <xsl:when test=". = '3412'">Uzbekistan </xsl:when>
            <xsl:when test=". = '3414'">Vanuatu </xsl:when>
            <xsl:when test=". = '3416'">Venezuela, Bolivarian Republic of </xsl:when>
            <xsl:when test=". = '3420'">Viet Nam </xsl:when>
            <xsl:when test=". = '3421'">Virgin Islands, British </xsl:when>
            <xsl:when test=". = '3422'">Virgin Islands, U.S. </xsl:when>
            <xsl:when test=". = '3425'">Wallis And Futuna </xsl:when>
            <xsl:when test=". = '3428'">Western Sahara </xsl:when>
            <xsl:when test=". = '3433'">Yemen </xsl:when>
            <xsl:when test=". = '3434'">Zambia </xsl:when>
            <xsl:when test=". = '3435'">Zimbabwe </xsl:when>
            <xsl:when test=". = '1342'">other: </xsl:when>
            <xsl:when test=". = '2207'">not specified </xsl:when>
            <xsl:when test=". = '1173'">no data </xsl:when>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="//xt:DataProtection/i6:confidentiality">
        <xsl:choose>
            <xsl:when test=". = '2732'">CBI </xsl:when>
            <xsl:when test=". = '2859'">IP </xsl:when>
            <xsl:when test=". = '3441'">no PA </xsl:when>
        </xsl:choose>
    </xsl:template>
</xsl:stylesheet>
